Welcome to Galaxy History Evaluator’s documentation! — Galaxy History Evaluator 2.0.0 documentation

# Welcome to Galaxy History Evaluator’s documentation!

A command-line tool to evaluate a Galaxy history, by comparing the history’s corresponding workflow with a reference workflow.

The output result are a JSON and HTML report files, reporting the differences between the history and the workflow.

Contents:

- Usage
  - Output
- Installation
  - Requirements
  - Installation via pip
- API documentation
- Contributing
  - What should I know before I get started?
  - How can I contribute?
  - Development
  - Tests
  - Documentation

# Indices and tables

- Index

- Module Index

- Search Page